@@ -1,20 +1,18 @@
 # %load_ext nb_black
 import pandas as pd
-import numpy as np
 
 
-# %matplotlib inline
-
-
-data = pd.read_csv("tests\mtsamples.csv")
+data = pd.read_csv(r"tests/mtsamples.csv")
 data = data.sort_values("medical_specialty")
 
-new_list = list(data[data["medical_specialty"] ==
-                " Dentistry"]["transcription"])
+new_list = list(
+    data[data["medical_specialty"] == "Dentistry"]["transcription"]
+    )
 
 
 data["dentistry"] = data["transcription"].map(
-    lambda x: 1 if x in new_list else -1)
+    lambda x: 1 if x in new_list else -1
+    )
 data = data.drop_duplicates(
     subset="transcription"
 )  # , 'medical_specialty'], keep="first")
@@ -24,6 +22,6 @@ data = data.drop(data[data["transcription"].isna()].index)
 
 data = data[["dentistry", "transcription", "medical_specialty"]]
 
-data=data[["transcription"]]
+data = data[["transcription"]]
 if __name__ == "__main__":
     print(data)
