@@ -1,21 +1,9 @@
-#!/usr/bin/env python
-
-"""Tests for `AuDoLab` package."""
-
 import pytest
-
-from click.testing import CliRunner
-
 import os
 import sys
-import numpy as np
-import pandas as pd
 sys.path.append(os.path.dirname(os.path.abspath(__file__)) + "/..")
-
-from AuDoLab import cli
 from AuDoLab import AuDoLab
-
-
+"""Tests for `AuDoLab` package."""
 
 
 @pytest.fixture
@@ -34,18 +22,7 @@ def test_content(response):
     # assert 'GitHub' in BeautifulSoup(response.content).title.string
 
 
-def test_command_line_interface():
-    """Test the CLI."""
-    runner = CliRunner()
-    result = runner.invoke(cli.main)
-    assert result.exit_code == 0
-    assert 'AuDoLab.cli.main' in result.output
-    help_result = runner.invoke(cli.main, ['--help'])
-    assert help_result.exit_code == 0
-    assert '--help  Show this message and exit.' in help_result.output
-
-
-# audo = AuDoLab.AuDoLab()
+audo = AuDoLab.AuDoLab()
 # # papers = audo.scrape_abstracts(
 # #     keywords=["dentistry", "teeth", "tooth"],
 # #     in_data="all_meta",
